@@ -74,6 +74,9 @@ def sa(	random_start,
 	coolings = int( math.ceil(  math.log(T_stop / T) / math.log(alpha)  ) )
 	
 	pbar = tqdm( range(coolings), unit='cooling' )
+
+	neighbours_tried_stats = { k:0 for k in [ f.__name__ for f in neighbours] }
+	neighbours_movement_stats = { k:0 for k in [ f.__name__ for f in neighbours] }
 	
 	for cooling in pbar:
 
@@ -90,10 +93,13 @@ def sa(	random_start,
 
 			new_state = random_neighbour(state)
 			new_cost = objective_function(new_state)
+
+			neighbours_tried_stats[ random_neighbour.__name__ ] += 1
 	
 			if acceptance(cost, new_cost, T) > random.random():
 				if new_cost != cost:
 					movements += 1
+					neighbours_movement_stats[ random_neighbour.__name__ ] += 1
 
 				state, cost = copy_state(new_state), new_cost
 
@@ -102,5 +108,11 @@ def sa(	random_start,
 				best_found = copy_state(state)
 					
 	print("---")
-	print("Best Found Cost: {:.8f}".format(best_found_cost))
+	print("Neighbour Statistics: \n(proportion of proposals which got accepted and changed the objective function)")
+	for neighbour in neighbours_tried_stats:
+		print( "   {:32s} : {:5.3f}".format(neighbour[:31], (neighbours_movement_stats[neighbour]/neighbours_tried_stats[neighbour]) ))
+
+	print("---")
+	print("(Local) Minimum Objective Value: \n   {:.8f}".format(best_found_cost))
+
 	return best_found, objective_function(best_found)
\ No newline at end of file
